@@ -15,7 +15,9 @@ serialize_to_httr <- function(request, response) {
       headers = request$headers %||% NULL,
       proxies = NULL,
       auth = NULL,
-      disk = response$disk
+      disk = response$disk,
+      fields = request$fields %||% NULL,
+      output = request$output %||% NULL
     )
   )
 
@@ -38,5 +40,23 @@ serialize_to_httr <- function(request, response) {
   resp$set_status(status = response$status$status_code %||% 200)
 
   # generate httr response
-  webmockr::build_httr_response(req, resp)
+  webmockr::build_httr_response(as_httr_request(req), resp)
+}
+
+keep_last <- function(...) {
+  x <- c(...)
+  x[!duplicated(names(x), fromLast = TRUE)]
+}
+httr_ops <- function(method, w) {
+  # if (!length(w)) return(w)
+  if (tolower(method) == "get") w$httpget <- TRUE
+  if (tolower(method) == "post") w$post <- TRUE
+  if (!tolower(method) %in% c("get", "post")) w$customrequest <- toupper(method)
+  return(w)
+}
+as_httr_request <- function(x) {
+  structure(list(method = toupper(x$method), url = x$url$url,
+    headers = keep_last(x$headers), fields = x$fields,
+    options = httr_ops(x$method, compact(keep_last(x$options))),
+    auth_token = x$auth, output = x$output), class = "request")
 }
